CompleteGenotypes: A function to remove missing data

Description Usage Arguments Examples

View source: R/CompleteGenotypes.R

Description

This function allows you to remove missing data from your file, by sampling from the allele frequency distributions at each locus

Usage

1
CompleteGenotypes(file, nloci, StartYear = 2008, ...)

Arguments

file

.csv Input file name with genotypic information

nloci

Number of loci in the data file

StartYear

Year that the simulation starts

Examples

1

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.