Resume.Rn.FRANzHatch: Resume running FRANz through R for parentage on muliple...

Description Usage Arguments Examples

View source: R/Rn.FRANzHatch.R

Description

This function facilitates the analysis of PseudoBabies simulations with the program FRANz

Usage

1
2
3
4
5
6
7
8
9
Resume.Rn.FRANzHatch(
  nSim,
  Miss_data = T,
  MissingVec,
  Geno_Error = T,
  ErrorVals,
  Markerfile = "MarkerPanels.csv",
  ShowProgress = FALSE
)

Arguments

Miss_data

Would you like to add missing data to the simulations? Defaults to FALSE

MissingVec

A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent.

Geno_Error

Would you like to add genotyping error to the simualated data? Defaults to FALSE

Markerfile

.csv for marker panels that will be evaluated.

ShowProgress

Would you like a progress bar to track the analysis. Defaults to FALSE

nSims

Number of replicate simulations

ErrorVec

A vector of error values for genotyping error. Required if Geno_Error=TRUE. Defaults to 0 and 2 percent.

Examples

1

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.