Sim.SG.Data: Simulate genotypes over a single year

Description Usage Arguments Examples

View source: R/Sim.SG.Data.R

Description

This function allows you to simulate multilocus genotypes under the assumption of completely random mating for a single year

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
Sim.SG.Data(
  Founders = "FoundersCompleteGenotypes.csv",
  Markerfile = "MarkerPanels.csv",
  NumSNPs = 93,
  NumuSats = 12,
  NB = 650,
  StartYear = as.numeric(format(Sys.Date(), "%Y")),
  nSim = 10,
  Geno_Error = F,
  ErrorVals,
  Miss_data = F,
  MissingVec,
  Programs = c("FRANz", "Colony"),
  SexInf,
  perl.dir,
  GPHomogeneity = FALSE,
  OffspringDist = "Poisson",
  SexInfo = F,
  lambda,
  Umin = 0,
  Umax = 1,
  nBprob,
  nBsize,
  ztnbprob,
  ztnbsize,
  MatingStr = "Polygyny"
)

Arguments

Founders

.csv file containing the genotypes to use for initiating the simulation. Use function CompleteGenotypes to remove missing data before performing simulations.

Markerfile

.csv for marker panels that will be evaluated.

NumSNPs

number of SNP markers.

NumuSats

number of microsatellite markers.

NB

number of crosses to perform. Defaults to 100.

StartYear

What year should the simulation start? Defaults to current year.

nSim

How many replicate simulations would you like to do? Defaults to 10.

Geno_Error

Would you like to add genotyping error to the simualated data? Defaults to FALSE

ErrorVals

How many different values of genotyping error for simulations. Required if Geno_Error=TRUE. Values specified in Loci_error.csv

Miss_data

Would you like to add missing data to the simulations? Defaults to FALSE

MissingVec

A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE.

Programs

Which programs would you like to create input files for? Defaults to c('FRANz','Colony')

SexInf

Use the sex of individuals in the parentage inference program

perl.dir

Full path to .csv.pl perl script distributed with FRANz for formatting input files. Required when FRANz is specified as a Program argument

GPHomogeneity

A logical to indicate if genepop should be run to compare the allele frequency distribution for all simulated datasets with the founders dataset. Defaults to FALSE

OffspringDist

What distribution should we use for the number of offspring produced for each cross. Options are Uniform (specify a min and a max), NegativeBinomial (specify a prob for the scale parameter see NegBinomial options), and Poisson (specify lambda).

SexInfo

Does your dataset have information on sex?

MatingStr

Should the simulation allow for polygamy, polygyny, polandry, or monogamy?

Examples

1
Sim_SG_Data()

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.