SumColony: Summarize the results from Colony2 analysis for parentage on...

Description Usage Arguments Examples

View source: R/SumColony.R

Description

This function summarizes the results from multiple runs of Colony2 for parentage inference from PseudoBabies simulations.

Usage

1
2
3
4
5
6
7
8
9
SumColony(
  nSim,
  Miss_data = T,
  MissingVec = c(0, 2.5),
  Geno_Error = T,
  ErrorVals = 1,
  Cutoff = 0.8,
  Markerfile = "MarkerPanels.csv"
)

Arguments

Miss_data

Would you like to add missing data to the simulations? Defaults to FALSE

MissingVec

A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent.

Geno_Error

Would you like to add genotyping error to the simualated data? Defaults to FALSE

ErrorVals

How many error values were specified in Loci_error.csv? Required if Geno_Error=TRUE. Defaults to 1 percent.

Cutoff

cutoff value for probability value accepting parentage.

Markerfile

.csv for marker panels that will be evaluated.

nSims

Number of replicate simulations

Examples

1

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.