SumFRANzHatch: Summarize the results from FRANz analysis for parentage on...

Description Usage Arguments Examples

View source: R/SumFRANzHatch.R

Description

This function summarizes the results from multiple runs of Colony2 for parentage inference from PseudoBabies simulations.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
SumFRANzHatch(
  nSim,
  Miss_data = FALSE,
  MissingVec = c(0, 2.5),
  Geno_Error = FALSE,
  ErrorVals,
  Cutoff,
  Markerfile,
  SavePlot = FALSE,
  FacetWrapBy = c("Panel", "Error", "MissDat"),
  ErrorLab,
  LODplots = FALSE
)

Arguments

Miss_data

Would you like to add missing data to the simulations? Defaults to FALSE

MissingVec

A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent.

Geno_Error

Would you like to add genotyping error to the simualated data? Defaults to FALSE

Cutoff

cutoff value for probability value accepting parentage.

Markerfile

.csv for marker panels that will be evaluated.

nSims

Number of replicate simulations

ErrorVec

A vector of error values for genotyping error. Required if Geno_Error=TRUE. Defaults to 0 and 2 percent.

Examples

1

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.