Summarize.LOD: Summarize the LOD scores from parentage inference with FRANz

Description Usage Arguments Examples

View source: R/Summarize.LOD.R

Description

This function summarizes the LOD scores from parentage inference of PseudoBabies simulations with the software FRANz.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
Summarize.LOD(
  AnalysisName,
  nSim,
  Miss_data = FALSE,
  MissingVec = c(0, 2.5),
  Geno_Error = FALSE,
  ErrorVec = c(0, 2),
  SavePlot = FALSE,
  PlotName = "LODsum",
  Plots = c("LCA", "PLCA", "PLCA", "PLICA"),
  ErrorLab,
  Markerfile,
  ...
)

Arguments

AnalysisName

Name of the Analysis

Miss_data

Would you like to add missing data to the simulations? Defaults to FALSE

MissingVec

A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent.

Geno_Error

Would you like to add genotyping error to the simualated data? Defaults to FALSE

ErrorVec

A vector of error values for genotyping error. Required if Geno_Error=TRUE. Defaults to 0 and 2 percent.

SavePlot

Do you want to create plots? Defaults to FALSE

PlotName

What do you want to name your plots? Defaults to LODsum

Plots

What plots do you want to create? Options are 'LCA','PLCA','PLCA','PLICA'.

ErrorLab

Label for Error in plots

Markerfile

.csv for marker panels that will be evaluated.

nSims

Number of replicate simulations

Examples

1
summarize.LOD()

patbarry6/PseudoBabies documentation built on Dec. 22, 2021, 6:41 a.m.