Description Usage Arguments Examples
View source: R/CompleteGenotypes.R
This function allows you to remove missing data from your file, by sampling from the allele frequency distributions at each locus
1 | CompleteGenotypes(file, nloci, StartYear = 2008, ...)
|
file |
.csv Input file name with genotypic information |
nloci |
Number of loci in the data file |
StartYear |
Year that the simulation starts |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.