Description Usage Arguments Examples
This function facilitates the analysis of PseudoBabies simulations with the program FRANz
1 2 3 4 5 6 7 8 9 10 11 12 13 | Resume.Rn.FRANz(
nSim,
Miss_data = T,
MissingVec,
Geno_Error = T,
ErrorVals,
Markerfile = "MarkerPanels.csv",
ShowProgress = FALSE,
MarkerNum.Res,
ErrorVec.Res,
MissingNum.Res,
Sim.Res
)
|
Miss_data |
Would you like to add missing data to the simulations? Defaults to FALSE |
MissingVec |
A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent. |
Geno_Error |
Would you like to add genotyping error to the simualated data? Defaults to FALSE |
Markerfile |
.csv for marker panels that will be evaluated. |
ShowProgress |
Would you like a progress bar to track the analysis. Defaults to FALSE |
nSims |
Number of replicate simulations |
ErrorVec |
A vector of error values for genotyping error. Required if Geno_Error=TRUE. Defaults to 0 and 2 percent. |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.