Description Usage Arguments Examples
This function allows you to simulate multilocus genotypes through time
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 | Sim.HatchExp(
AnalysisName,
Founders,
AOMfile,
Markerfile = "MarkerPanels.csv",
NumuSats,
NumSNPs,
NB = 600,
NumYears = 19,
StartYear = format(Sys.Date(), "%Y"),
nSim = 10,
Geno_Error = FALSE,
Miss_data = FALSE,
MissingVec = c(0, 2.5),
ErrorVals = 1,
Programs = c("FRANz", "Colony"),
SexInf = FALSE,
perl.dir,
GPHomogeneity = FALSE,
OffspringDist = "Poisson",
SexInfo = FALSE,
MatingStr = "Polygamy",
lambda = 2,
Umin,
Umax,
nBprob,
HatchYear,
SireHatch,
DamHatch,
Hatch_Dist,
lambda_h = 2,
Umin_h,
Umax_h,
nBprob_h,
BreedDesign = "1:2"
)
|
AnalysisName |
name of the analysis |
Founders |
.csv file containing the genotypes to use for initiating the simulation. Use function CompleteGenotypes to remove missing data before performing simulations. |
AOMfile |
.csv of Age of maturity estimates. |
Markerfile |
.csv for marker panels that will be evaluated. |
NumuSats |
number of microsatellite markers. |
NumSNPs |
number of SNP markers. |
NB |
number of crosses to perform each year. Defaults to 100. |
NumYears |
How many years should the simulation last? Defaults to 50. |
StartYear |
What year should the simulation start? Defaults to current year. |
Geno_Error |
Would you like to add genotyping error to the simualated data? Defaults to FALSE |
Miss_data |
Would you like to add missing data to the simulations? Defaults to FALSE |
MissingVec |
A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent. |
Programs |
Which programs would you like to create input files for? Defaults to c('FRANz','Colony') |
SexInf |
Use the sex of individuals in the parentage inference program |
perl.dir |
File path for the perl directory for FRANz utility for formating. |
OffspringDist |
What distribution should we use for the number of offspring produced for each cross. Options are Uniform (specify a min and a max), NegativeBinomial (specify a prob for the scale parameter see |
SexInfo |
Does your dataset have information on sex? |
MatingStr |
Should the simulation allow for polygamy, polygyny, polandry, or monogomy? |
SireHatch |
How many individuals to collect for the sires |
DamHatch |
How many individuals to collect for the dams |
BreedDesign |
What is the breeding design for the experiment? Defaults to 2:1. |
nSim=10 |
How many replicate simulations would you like to do? Defaults to 10. |
ErrorVec |
A vector of error values for genotyping error. Required if Geno_Error=TRUE. Defaults to 0 and 2 percent. |
HatchYr |
In what year do we want to implement a hatchery experiment |
HatchDist |
What distrbution do we want to use for the hatchery offspring? |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.