Description Usage Arguments Examples
This function summarizes the results from multiple runs of Colony2 for parentage inference from PseudoBabies simulations.
1 2 3 4 5 6 7 8 9 |
Miss_data |
Would you like to add missing data to the simulations? Defaults to FALSE |
MissingVec |
A vector of values for the percent of missing data in the input file. Required if Miss_data=TRUE. Defaults to 0 and 2.5 percent. |
Geno_Error |
Would you like to add genotyping error to the simualated data? Defaults to FALSE |
ErrorVals |
How many error values were specified in Loci_error.csv? Required if Geno_Error=TRUE. Defaults to 1 percent. |
Cutoff |
cutoff value for probability value accepting parentage. |
Markerfile |
.csv for marker panels that will be evaluated. |
nSims |
Number of replicate simulations |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.